clear
use "/Users/Marina/Dropbox/FINISHED/Network Bargaining Experiement/Experiments/DataAnalysis/Structured_2015/Analysis/data_original.dta"

***********************
**    VARIABLES      **
***********************

gen finalpayoff = potentialpayoff if matchending!=. & matchending!=2 

** Variables for unique session, unique id and unique game-group id
gen sessionun = game*100+separation*10 + session*1
gen uniqueid = sessionun*100+clientid

** Efficiency of Final Match

sort sessionun match group round index
gen     totalpayoff = finalpayoff[_n]+finalpayoff[_n+1]+finalpayoff[_n+2]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

gen     temp = 1 if separation==0 & totalpayoff==40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==0 & totalpayoff<40 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0
replace temp = 1 if separation==1 & totalpayoff>=37.1 & totalpayoff<=40 & matchending!=. & matchending!=2 & index==0
replace temp = 0 if separation==1 & totalpayoff<37.1 & totalpayoff>0 & matchending!=. & matchending!=2 & index==0

bysort sessionun match groupid: egen efficient = max(temp)
drop temp

** sum of strong players' payoffs
sort sessionun match group round index
gen  sumstrongpayoffs = finalpayoff[_n+1]+finalpayoff[_n+3] if matchending!=. & matchending!=2 & index==0

** dummies for each game
gen game15 = (game==15)
gen game25 = (game==25)
gen game30 = (game==30)

** network position 
gen strong = (index==1 | index==3)

** variable that keeps track of who is matched and who is not
gen matched = (roundpotentialpayoff!=.)
replace matched = . if roundpotentialpayoff==0 & (matchending==1 | matchending==2 | matchending==3)

** variable that takes value 1 if all players are unmatched
sort sessionun match groupid round index
gen     allnotmatched = 1 if round==0
replace allnotmatched = 1 if round>=1 & index==0 & matched[_n-4]==0 & matched[_n-3]==0  & matched[_n-2]==0 & matched[_n-1]==0 
replace allnotmatched = 1 if round>=1 & index==1 & matched[_n-5]==0 & matched[_n-4]==0  & matched[_n-3]==0 & matched[_n-2]==0 
replace allnotmatched = 1 if round>=1 & index==2 & matched[_n-6]==0 & matched[_n-5]==0  & matched[_n-4]==0 & matched[_n-3]==0 
replace allnotmatched = 1 if round>=1 & index==3 & matched[_n-7]==0 & matched[_n-6]==0  & matched[_n-5]==0 & matched[_n-4]==0 
replace allnotmatched = 0 if round>=1 & allnotmatched==.

** responder's amount in the selected offer
gen     responderamounttemp = 20-proposeamount if responder==3 & selectedproposer==0 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==0 & selectedproposer==3 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==2 & selectedproposer==1 & selectedproposer==index 
replace responderamounttemp = 20-proposeamount if responder==1 & selectedproposer==2 & selectedproposer==index 
replace responderamounttemp = 30-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==30
replace responderamounttemp = 30-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==30
replace responderamounttemp = 25-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==25
replace responderamounttemp = 25-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==25
replace responderamounttemp = 15-proposeamount if responder==1 & selectedproposer==3 & selectedproposer==index  & game==15
replace responderamounttemp = 15-proposeamount if responder==3 & selectedproposer==1 & selectedproposer==index  & game==15

bysort sessionun match groupid round: egen responderamount = max(responderamounttemp)
drop responderamounttemp


 
** Regression (1)
reg efficient game25 game30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
test game25 game30
test game30 = game25
test _cons + game25 = 0.72
test _cons + game30 = 0.50

** Regression (2)
gen     firstmoverweaktemp = 1 if round==0 & (selectedproposer==0 | selectedproposer==2)
replace firstmoverweaktemp = 0 if round==0 & (selectedproposer==1 | selectedproposer==3)

bysort sessionun match groupid: egen firstmoverweak = max(firstmoverweaktemp)
drop firstmoverweaktemp

gen firstmoverstrong = (firstmoverweak==0)
gen firstmoverstrong15 = (firstmoverstrong==1 & game==15)
gen firstmoverstrong25 = (firstmoverstrong==1 & game==25)
gen firstmoverstrong30 = (firstmoverstrong==1 & game==30)

reg efficient firstmoverstrong15  game25 firstmoverstrong25 game30 firstmoverstrong30 if separation==0 & matchend!=. & matchend!=2 & index==0 & match>4, cluster(sessionun)
test  firstmoverstrong30 =  firstmoverstrong25

